# Embedded file name: /usr/lib/enigma2/python/Plugins/Extensions/LiteHD/plugin.py
from Components.ActionMap import ActionMap
from Components.config import config, getConfigListEntry, ConfigText, ConfigPassword, ConfigClock, ConfigSelection, ConfigSubsection, ConfigYesNo, configfile, NoSave
from Components.ConfigList import ConfigListScreen
from Components.Label import Label
from Plugins.Plugin import PluginDescriptor
from Screens.Screen import Screen
from Components.Sources.List import List
from Components.Language import language
from Tools.Directories import resolveFilename, SCOPE_PLUGINS, SCOPE_LANGUAGE
from Screens.PluginBrowser import PluginBrowser
from Components.ScrollLabel import ScrollLabel
from Screens.MessageBox import MessageBox
from Screens.Standby import TryQuitMainloop
from Components.Sources.StaticText import StaticText
from Components.Pixmap import Pixmap
from Components.Console import Console as iConsole
from enigma import getDesktop
from os import environ
import os
import gettext

###########################################################################


config.plugins.LiteHD = ConfigSubsection()
config.plugins.LiteHD.style = ConfigSelection(default='default', choices=[('default', _('default')),
 ('blue', _('blue')),
 ('violet', _('violet')),
 ('black', _('black')),
 ('green', _('green'))])
 

###########################################################################
class LiteHDConfig(ConfigListScreen, Screen):
    skin = """
    <screen name="LiteHDConfig" position="center,110" size="750,520" title="LiteHD sKIn setup">
		<widget position="20,20" size="720,100" name="config" itemHeight="30" scrollbarMode=" showOnDemand" />
		<ePixmap position="10,475" zPosition="1" size="30,30" pixmap="/usr/lib/enigma2/python/Plugins/Extensions/LiteHDConfig/buttons/red.png" alphatest="blend" />
		<ePixmap position="215,475" zPosition="1" size="30,30" pixmap="/usr/lib/enigma2/python/Plugins/Extensions/LiteHDConfig/buttons/green.png" alphatest="blend" />
		<ePixmap position="420,475" zPosition="1" size="30,30" pixmap="/usr/lib/enigma2/python/Plugins/Extensions/LiteHDConfig/buttons/yellow.png" alphatest="blend" />
		<widget source="red_key" render="Label" position="45,477" zPosition="2" size="165,25" font="Regular;20" halign="left" valign="center"  transparent="1" />
		<widget source="green_key" render="Label" position="250,477" zPosition="2" size="165,25" font="Regular;20" halign="left" valign="center"  transparent="1" />
		<widget source="yellow_key" render="Label" position="455,477" zPosition="2" size="200,25" font="Regular;20" halign="left" valign="center"  transparent="1" />
		<widget name="Preview" position="center,150" size="480,270" zPosition="5" alphatest="blend" />
    </screen>""" 


    def __init__(self, session):
        self.session = session
        Screen.__init__(self, session)
        self.setTitle(_('LiteHD Skin Setup'))
        self.iConsole = iConsole()
        self.list = []
        self.list.append(getConfigListEntry(_('Color Style'), config.plugins.LiteHD.style))
        ConfigListScreen.__init__(self, self.list)
		
        self['Preview'] = Pixmap()
        self['red_key'] = StaticText(_('Close'))
        self['green_key'] = StaticText(_('Save'))
        self['yellow_key'] = StaticText(_('Restart GUI'))
        self['setupActions'] = ActionMap(['SetupActions', 'ColorActions'], {'red': self.cancel,
         'cancel': self.close,
         'green': self.save,
	     'yellow': self.restart,
         'ok': self.save}, -2)
        self.onLayoutFinish.append(self.Preview)

    def Preview(self):
        self['Preview'].instance.setPixmapFromFile('/usr/lib/enigma2/python/Plugins/Extensions/LiteHDConfig/preview/%sstyle.png' % config.plugins.LiteHD.style.value)

    def keyLeft(self):
        ConfigListScreen.keyLeft(self)
        self.Preview()

    def keyRight(self):
        ConfigListScreen.keyRight(self)
        self.Preview()

    def exit(self):
        self.close()

    def cancel(self):
        for i in self['config'].list:
            i[1].cancel()

        self.session.openWithCallback(self.exit, About)
		


    def save(self):
        self.iConsole.ePopen('tar -C/ -xzpvf /usr/share/enigma2/LiteHD/styles/%sstyle.tar.gz' % config.plugins.LiteHD.style.value)
        config.plugins.LiteHD.style.save()
        configfile.save()
        self.mbox = self.session.open(MessageBox, _('configuration is saved'), MessageBox.TYPE_INFO, timeout=4)

    def restart(self):
        self.session.open(TryQuitMainloop, 3)

    def about(self):
        self.session.openWithCallback(self.exit, LiteHDAbout)


class LiteHDAbout(Screen):
    skin = """
	<screen name="LiteHDAbout" position="center,center" size="650,280" title="About" >
		<widget name="infom" position="5,100" size="640,260" valign="center" halign="center" zPosition="5" transparent="1" font="Regular;30"/>
    </screen>""" 

    def __init__(self, session):
        self.session = session
        Screen.__init__(self, session)
        self['actions'] = ActionMap(['SetupActions'], {'cancel': self.exit,
         'ok': self.exit}, -1)
        self.info = 'https://github.com/digiteng/'
        self['infom'] = Label(self.info)

    def exit(self):
        self.close()

###########################################################################
		
def main(session, **kwargs):
    session.open(LiteHDConfig)
	
def Plugins(**kwargs):
    return PluginDescriptor(name=_('LiteHD Setup'), description=_('skin style setup'), where=[PluginDescriptor.WHERE_PLUGINMENU, PluginDescriptor.WHERE_EXTENSIONSMENU], icon='plugin.png', fnc=main)